/*
 * Licensed under the License located at push-android-client/LICENSE
 * You may not use this file except in compliance with the License.
 */
package com.mobify.push.pushclient;

import android.content.Context;
import android.util.NoSuchPropertyException;

import java.security.KeyException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Map;

public class MessageProcessor {
    private static final String TAG = MessageProcessor.class.getName();

    public static final String TITLE_KEY_DATA_PAYLOAD = "title";
    public static final String MESSAGE_KEY_DATA_PAYLOAD = "message";
    public static final String URL_KEY_DATA_PAYLOAD = "url";
    public static final String EXPIRY_KEY_DATA_PAYLOAD = "expiryTime";
    public static final String MESSAGE_ID_KEY_DATA_PAYLOAD = "message_id";

    private static final ArrayList<String> KEYS = new ArrayList<String>(
            Arrays.asList(TITLE_KEY_DATA_PAYLOAD,
                    MESSAGE_KEY_DATA_PAYLOAD,
                    URL_KEY_DATA_PAYLOAD,
                    EXPIRY_KEY_DATA_PAYLOAD,
                    MESSAGE_ID_KEY_DATA_PAYLOAD));

    protected Context context;
    protected PushNotificationBuilder notificationBuilder;

    public MessageProcessor(Context context) {
        this.context = context;
        notificationBuilder = new PushNotificationBuilder(context);
    }

    public void processMessage(Map<String, String> data) throws Exception {
        for (String key : KEYS) {
            if (!data.containsKey(key)) {
                throw new KeyException("FCM Payload does not contain key: " + key);
            }
        }

        String messageTitle = retrieveFromDataMap(data, TITLE_KEY_DATA_PAYLOAD);
        String messageContents = retrieveFromDataMap(data, MESSAGE_KEY_DATA_PAYLOAD);
        String messageUrlLink = retrieveFromDataMap(data, URL_KEY_DATA_PAYLOAD);
        String messageExpiry = retrieveFromDataMap(data, EXPIRY_KEY_DATA_PAYLOAD);
        String messageId = retrieveFromDataMap(data, MESSAGE_ID_KEY_DATA_PAYLOAD);

        notificationBuilder.postNotification(messageTitle, messageContents, messageUrlLink, messageExpiry, messageId);
    }

    protected static String retrieveFromDataMap(Map<String, String> data, String key) throws NoSuchPropertyException {
        String value;
        try {
            value = data.get(key);
            if (value == null) {
                throw new ClassCastException();
            }
        } catch (ClassCastException e) {
            throw new NoSuchPropertyException(key + " is in map but did not contain a string value.");
        }
        return value;
    }
}
