/*
 * Licensed under the License located at push-android-client/LICENSE
 * You may not use this file except in compliance with the License.
 */
package com.mobify.push.pushclient.service;

import android.content.Context;
import android.content.SharedPreferences;
import android.util.Log;

import com.google.firebase.messaging.FirebaseMessagingService;
import com.google.firebase.messaging.RemoteMessage;
import com.mobify.push.pushclient.MessageProcessor;
import com.mobify.push.pushclient.R;

import java.util.Map;

import androidx.work.WorkManager;

public class PushFcmListenerService extends FirebaseMessagingService {
    private static final String TAG = PushFcmListenerService.class.getName();

    @Override
    public void onMessageReceived(RemoteMessage message) {
        String from = message.getFrom();
        Map<String, String> data = message.getData();
        Log.d(TAG, "Message received from: " + from + " data: " + data.toString());

        MessageProcessor messageProcessor = new MessageProcessor(this);

        try {
            messageProcessor.processMessage(data);
        } catch (Exception e) {
            Log.e(TAG, "Cannot post notification: " + e.getMessage() + " With data: " + data.toString());
        }
    }

    @Override
    public void onNewToken(String token) {
        super.onNewToken(token);
        SharedPreferences sharedPreferences = getSharedPreferences(
                getString(R.string.push_client_shared_pref_file_key), Context.MODE_PRIVATE);
        String fcmTokenPrefKey = getString(R.string.fcm_token_pref_key);
        sharedPreferences.edit().putString(fcmTokenPrefKey, token).apply();

        Log.d(TAG, "Firebase token generated: " + token);

        // We might not need to persist the token in Shared Preferences anymore. We could pass it through to the next work manager task but probably not necessary.
        //Here we need to call PusheenRegistrar and update id with pusheen

        WorkManager.getInstance().enqueue(PusheenRegistrationWorker.createTask());
    }
}
