/*
 * Licensed under the License located at push-android-client/LICENSE
 * You may not use this file except in compliance with the License.
 */
package com.mobify.push.pushclient.service;

import android.content.Context;
import android.support.annotation.NonNull;
import android.util.Log;

import com.mobify.push.pushclient.PusheenRegistrar;

import androidx.work.Constraints;
import androidx.work.NetworkType;
import androidx.work.OneTimeWorkRequest;
import androidx.work.Worker;
import androidx.work.WorkerParameters;

public class PusheenRegistrationWorker extends Worker {
    private static final String TAG = PusheenRegistrationWorker.class.getName();

    public PusheenRegistrationWorker(@NonNull Context context, @NonNull WorkerParameters workerParams) {
        super(context, workerParams);
    }

    @Override
    public Worker.Result doWork() {
        PusheenRegistrar pusheenRegistrar = new PusheenRegistrar(this.getApplicationContext());

        try {
            pusheenRegistrar.registerToken();
        } catch (Exception e) {
            Log.d(TAG, "Failed Pusheen registration attempt. Rescheduling.", e);
            return Result.retry();
        }
        return Result.success();
    }

    public static OneTimeWorkRequest createTask() {
        Constraints pusheenConstraints =
                new Constraints.Builder()
                        .setRequiredNetworkType(NetworkType.CONNECTED)
                        .build();
        return new OneTimeWorkRequest.Builder(PusheenRegistrationWorker.class)
                .setConstraints(pusheenConstraints)
                .build();
    }
}
