/*
 * Licensed under the License located at push-android-client/LICENSE
 * You may not use this file except in compliance with the License.
 */
package com.mobify.push.pushclient.utilities;

import java.util.Date;
import java.util.Locale;
import java.util.TimeZone;
import java.util.concurrent.TimeUnit;

public class LocaleUtilities {
    private static final String TAG = LocaleUtilities.class.getName();

    private static final int SWAP_OFFSET_SIGN = -1;

    public static int getUtcOffsetInMinutes() {
        return getUtcOffsetInMinutes(TimeZone.getDefault());
    }

    public static int getUtcOffsetInMinutes(TimeZone timeZone) {
        long offset = timeZone.getOffset(new Date().getTime());

        // Multiply by -ve 1 b/c Pusheen server is expecting offset using opposite sign
        // than the getOffset method returns
        // Fine to cast long to int b/c offset will only be 12-14 hrs
        return ((int) TimeUnit.MILLISECONDS.toMinutes(offset)) * SWAP_OFFSET_SIGN;
    }

    public static String getDeviceLanguageAndCountry() {
        return getDeviceLanguageAndCountry(Locale.getDefault());
    }

    public static String getDeviceLanguageAndCountry(Locale locale) {
        return locale.getLanguage() + "_" + locale.getCountry();
    }
}
