/*
 * Licensed under the License located at push-android-client/LICENSE
 * You may not use this file except in compliance with the License.
 */
package com.mobify.push.pushclient.utilities;

import org.junit.Test;

import java.util.Locale;
import java.util.SimpleTimeZone;

import static org.junit.Assert.assertEquals;

public class LocaleUtilitiesTest {
    static final int HOURS_TO_MILLISECONDS = 60 * 60 * 1000;
    @Test
    public void getUtcOffsetInMinutesVancouverCanada() {
        int utcOffsetInMinutes = LocaleUtilities.getUtcOffsetInMinutes(new SimpleTimeZone(-8 * HOURS_TO_MILLISECONDS, "America/Vancouver"));
        assertEquals(480, utcOffsetInMinutes);
    }

    @Test
    public void getUtcOffsetInMinutesParisFrance() {
        int utcOffsetInMinutes = LocaleUtilities.getUtcOffsetInMinutes(new SimpleTimeZone(1 * HOURS_TO_MILLISECONDS, "Europe/Paris"));
        assertEquals(-60, utcOffsetInMinutes);
    }

    @Test
    public void getUtcOffsetInMinutesNewYorkUSA() {
        int utcOffsetInMinutes = LocaleUtilities.getUtcOffsetInMinutes(new SimpleTimeZone(-4 * HOURS_TO_MILLISECONDS, "America/New_York"));
        assertEquals(240, utcOffsetInMinutes);
    }

    @Test
    public void getUtcOffsetInMinutesAnchorageUSA() {
        int utcOffsetInMinutes = LocaleUtilities.getUtcOffsetInMinutes(new SimpleTimeZone(-8 * HOURS_TO_MILLISECONDS, "America/Anchorage"));
        assertEquals(480, utcOffsetInMinutes);
    }

    @Test
    public void getUtcOffsetInMinutesHonoluluUSA() {
        int utcOffsetInMinutes = LocaleUtilities.getUtcOffsetInMinutes(new SimpleTimeZone(-10 * HOURS_TO_MILLISECONDS, "America/Honolulu"));
        assertEquals(600, utcOffsetInMinutes);
    }

    @Test
    public void getUtcOffsetInMinutesRiyadhAsia() {
        int utcOffsetInMinutes = LocaleUtilities.getUtcOffsetInMinutes(new SimpleTimeZone(3 * HOURS_TO_MILLISECONDS, "Asia/Riyadh"));
        assertEquals(-180, utcOffsetInMinutes);
    }

    @Test
    public void getUtcOffsetInMinutesTokyoJapan() {
        int utcOffsetInMinutes = LocaleUtilities.getUtcOffsetInMinutes(new SimpleTimeZone(9 * HOURS_TO_MILLISECONDS, "Asia/Tokyo"));
        assertEquals(-540, utcOffsetInMinutes);
    }

    @Test
    public void getDeviceLanguageAndCountryEnglishCanada() {
        String languageAndCountry = LocaleUtilities.getDeviceLanguageAndCountry(Locale.CANADA);
        assertEquals("en_CA", languageAndCountry);
    }

    @Test
    public void getDeviceLanguageAndCountryFrenchCanada() {
        String languageAndCountry = LocaleUtilities.getDeviceLanguageAndCountry(Locale.CANADA_FRENCH);
        assertEquals("fr_CA", languageAndCountry);
    }

    @Test
    public void getDeviceLanguageAndCountryUsa() {
        String languageAndCountry = LocaleUtilities.getDeviceLanguageAndCountry(Locale.US);
        assertEquals("en_US", languageAndCountry);
    }

    @Test
    public void getDeviceLanguageAndCountrySpanishUsa() {
        String languageAndCountry = LocaleUtilities.getDeviceLanguageAndCountry(new Locale("es", "US"));
        assertEquals("es_US", languageAndCountry);
    }

    @Test
    public void getDeviceLanguageAndCountryUK() {
        String languageAndCountry = LocaleUtilities.getDeviceLanguageAndCountry(Locale.UK);
        assertEquals("en_GB", languageAndCountry);
    }

    @Test
    public void getDeviceLanguageAndCountryChina() {
        String languageAndCountry = LocaleUtilities.getDeviceLanguageAndCountry(Locale.CHINA);
        assertEquals("zh_CN", languageAndCountry);
    }

    @Test
    public void getDeviceLanguageAndCountrySaudiArabia() {
        String languageAndCountry = LocaleUtilities.getDeviceLanguageAndCountry(new Locale("ar", "SA"));
        assertEquals("ar_SA", languageAndCountry);
    }
}
